@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2019, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2017, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -212,14 +212,14 @@ AslCommandLine (
 
     BadCommandLine = AslDoOptions (argc, argv, FALSE);
 
-    if (AslGbl_DoTemplates)
+    if (Gbl_DoTemplates)
     {
         Status = DtCreateTemplates (argv);
         if (ACPI_FAILURE (Status))
         {
             exit (-1);
         }
-        exit (0);
+        exit (1);
     }
 
     /* Next parameter must be the input filename */
@@ -231,10 +231,10 @@ AslCommandLine (
         BadCommandLine = TRUE;
     }
 
-    if (AslGbl_DoSignon)
+    if (Gbl_DoSignon)
     {
         printf (ACPI_COMMON_SIGNON (ASL_COMPILER_NAME));
-        if (AslGbl_IgnoreErrors)
+        if (Gbl_IgnoreErrors)
         {
             printf ("Ignoring all errors, forcing AML file generation\n\n");
         }
@@ -297,7 +297,7 @@ AslDoOptions (
         {
         case 'r':
 
-            AslGbl_EnableReferenceTypechecking = TRUE;
+            Gbl_EnableReferenceTypechecking = TRUE;
             break;
 
         default:
@@ -318,16 +318,16 @@ AslDoOptions (
 
             printf ("Debug ASL to ASL+ conversion\n");
 
-            AslGbl_DoAslConversion = TRUE;
-            AslGbl_FoldConstants = FALSE;
-            AslGbl_IntegerOptimizationFlag = FALSE;
-            AslGbl_ReferenceOptimizationFlag = FALSE;
-            AslGbl_OptimizeTrivialParseNodes = FALSE;
+            Gbl_DoAslConversion = TRUE;
+            Gbl_FoldConstants = FALSE;
+            Gbl_IntegerOptimizationFlag = FALSE;
+            Gbl_ReferenceOptimizationFlag = FALSE;
+            Gbl_OptimizeTrivialParseNodes = FALSE;
             AcpiGbl_CaptureComments = TRUE;
             AcpiGbl_DoDisassemblerOptimizations = FALSE;
             AcpiGbl_DebugAslConversion = TRUE;
             AcpiGbl_DmEmitExternalOpcodes = TRUE;
-            AslGbl_DoExternalsInPlace = TRUE;
+            Gbl_DoExternalsInPlace = TRUE;
 
             return (0);
 
@@ -336,8 +336,8 @@ AslDoOptions (
             AslCompilerdebug = 1; /* same as yydebug */
             DtParserdebug = 1;
             PrParserdebug = 1;
-            AslGbl_DebugFlag = TRUE;
-            AslGbl_KeepPreprocessorTempFile = TRUE;
+            Gbl_DebugFlag = TRUE;
+            Gbl_KeepPreprocessorTempFile = TRUE;
             break;
 
         case 'p':   /* Prune ASL parse tree */
@@ -349,13 +349,13 @@ AslDoOptions (
                 return (-1);
             }
 
-            AslGbl_PruneParseTree = TRUE;
-            AslGbl_PruneDepth = (UINT8) strtoul (AcpiGbl_Optarg, NULL, 0);
+            Gbl_PruneParseTree = TRUE;
+            Gbl_PruneDepth = (UINT8) strtoul (AcpiGbl_Optarg, NULL, 0);
             break;
 
         case 's':
 
-            AslGbl_DebugFlag = TRUE;
+            Gbl_DebugFlag = TRUE;
             break;
 
         case 't':
@@ -367,7 +367,7 @@ AslDoOptions (
                 return (-1);
             }
 
-            AslGbl_PruneType = (UINT8) strtoul (AcpiGbl_Optarg, NULL, 0);
+            Gbl_PruneType = (UINT8) strtoul (AcpiGbl_Optarg, NULL, 0);
             break;
 
         default:
@@ -386,21 +386,21 @@ AslDoOptions (
         case 'a':
 
             printf ("Convert ASL to ASL+ with comments\n");
-            AslGbl_DoAslConversion = TRUE;
-            AslGbl_FoldConstants = FALSE;
-            AslGbl_IntegerOptimizationFlag = FALSE;
-            AslGbl_ReferenceOptimizationFlag = FALSE;
-            AslGbl_OptimizeTrivialParseNodes = FALSE;
+            Gbl_DoAslConversion = TRUE;
+            Gbl_FoldConstants = FALSE;
+            Gbl_IntegerOptimizationFlag = FALSE;
+            Gbl_ReferenceOptimizationFlag = FALSE;
+            Gbl_OptimizeTrivialParseNodes = FALSE;
             AcpiGbl_CaptureComments = TRUE;
             AcpiGbl_DoDisassemblerOptimizations = FALSE;
             AcpiGbl_DmEmitExternalOpcodes = TRUE;
-            AslGbl_DoExternalsInPlace = TRUE;
+            Gbl_DoExternalsInPlace = TRUE;
 
             return (0);
 
         case 'r':
 
-            AslGbl_NoResourceChecking = TRUE;
+            Gbl_NoResourceChecking = TRUE;
             break;
 
         default:
@@ -416,13 +416,13 @@ AslDoOptions (
         {
         case '^':
 
-            AslGbl_DoCompile = FALSE;
+            Gbl_DoCompile = FALSE;
             break;
 
         case 'a':
 
-            AslGbl_DoCompile = FALSE;
-            AslGbl_DisassembleAll = TRUE;
+            Gbl_DoCompile = FALSE;
+            Gbl_DisassembleAll = TRUE;
             break;
 
         case 'b':   /* Do not convert buffers to resource descriptors */
@@ -441,7 +441,7 @@ AslDoOptions (
 
         case 'l':   /* Use legacy ASL code (not ASL+) for disassembly */
 
-            AslGbl_DoCompile = FALSE;
+            Gbl_DoCompile = FALSE;
             AcpiGbl_CstyleDisassembly = FALSE;
             break;
 
@@ -487,7 +487,7 @@ AslDoOptions (
         {
         case '^':   /* Ignore errors and force creation of aml file */
 
-            AslGbl_IgnoreErrors = TRUE;
+            Gbl_IgnoreErrors = TRUE;
             break;
 
         case 'e':   /* Disassembler: Get external declaration file */
@@ -497,7 +497,7 @@ AslDoOptions (
                 return (-1);
             }
 
-            AslGbl_ExternalRefFilename = AcpiGbl_Optarg;
+            Gbl_ExternalRefFilename = AcpiGbl_Optarg;
             break;
 
         default:
@@ -509,7 +509,7 @@ AslDoOptions (
 
     case 'G':
 
-        AslGbl_CompileGeneric = TRUE;
+        Gbl_CompileGeneric = TRUE;
         break;
 
     case 'g':   /* Get all ACPI tables */
@@ -572,14 +572,14 @@ AslDoOptions (
 
             /* Produce assembly code include file */
 
-            AslGbl_AsmIncludeOutputFlag = TRUE;
+            Gbl_AsmIncludeOutputFlag = TRUE;
             break;
 
         case 'c':
 
             /* Produce C include file */
 
-            AslGbl_C_IncludeOutputFlag = TRUE;
+            Gbl_C_IncludeOutputFlag = TRUE;
             break;
 
         case 'n':
@@ -604,7 +604,7 @@ AslDoOptions (
 
             /* Produce listing file (Mixed source/aml) */
 
-            AslGbl_ListingFlag = TRUE;
+            Gbl_ListingFlag = TRUE;
             AcpiGbl_DmOpt_Listing = TRUE;
             break;
 
@@ -612,35 +612,35 @@ AslDoOptions (
 
             /* Produce preprocessor output file */
 
-            AslGbl_PreprocessorOutputFlag = TRUE;
+            Gbl_PreprocessorOutputFlag = TRUE;
             break;
 
         case 'm':
 
             /* Produce hardware map summary file */
 
-            AslGbl_MapfileFlag = TRUE;
+            Gbl_MapfileFlag = TRUE;
             break;
 
         case 'n':
 
             /* Produce namespace file */
 
-            AslGbl_NsOutputFlag = TRUE;
+            Gbl_NsOutputFlag = TRUE;
             break;
 
         case 's':
 
             /* Produce combined source file */
 
-            AslGbl_SourceOutputFlag = TRUE;
+            Gbl_SourceOutputFlag = TRUE;
             break;
 
         case 'x':
 
             /* Produce cross-reference file */
 
-            AslGbl_CrossReferenceOutput = TRUE;
+            Gbl_CrossReferenceOutput = TRUE;
             break;
 
         default:
@@ -652,17 +652,17 @@ AslDoOptions (
 
     case 'm':   /* Set line buffer size */
 
-        AslGbl_LineBufferSize = (UINT32) strtoul (AcpiGbl_Optarg, NULL, 0) * 1024;
-        if (AslGbl_LineBufferSize < ASL_DEFAULT_LINE_BUFFER_SIZE)
+        Gbl_LineBufferSize = (UINT32) strtoul (AcpiGbl_Optarg, NULL, 0) * 1024;
+        if (Gbl_LineBufferSize < ASL_DEFAULT_LINE_BUFFER_SIZE)
         {
-            AslGbl_LineBufferSize = ASL_DEFAULT_LINE_BUFFER_SIZE;
+            Gbl_LineBufferSize = ASL_DEFAULT_LINE_BUFFER_SIZE;
         }
-        printf ("Line Buffer Size: %u\n", AslGbl_LineBufferSize);
+        printf ("Line Buffer Size: %u\n", Gbl_LineBufferSize);
         break;
 
     case 'n':   /* Parse only */
 
-        AslGbl_ParseOnlyFlag = TRUE;
+        Gbl_ParseOnlyFlag = TRUE;
         break;
 
     case 'o':   /* Control compiler AML optimizations */
@@ -673,10 +673,10 @@ AslDoOptions (
 
             /* Disable all optimizations */
 
-            AslGbl_FoldConstants = FALSE;
-            AslGbl_IntegerOptimizationFlag = FALSE;
-            AslGbl_ReferenceOptimizationFlag = FALSE;
-            AslGbl_OptimizeTrivialParseNodes = FALSE;
+            Gbl_FoldConstants = FALSE;
+            Gbl_IntegerOptimizationFlag = FALSE;
+            Gbl_ReferenceOptimizationFlag = FALSE;
+            Gbl_OptimizeTrivialParseNodes = FALSE;
 
             break;
 
@@ -684,7 +684,7 @@ AslDoOptions (
 
             /* Display compile time(s) */
 
-            AslGbl_CompileTimesFlag = TRUE;
+            Gbl_CompileTimesFlag = TRUE;
             break;
 
         case 'd':
@@ -708,35 +708,35 @@ AslDoOptions (
              * No affect if Gbl_DoExternals is false.
              */
 
-            AslGbl_DoExternalsInPlace = TRUE;
+            Gbl_DoExternalsInPlace = TRUE;
             break;
 
         case 'f':
 
             /* Disable folding on "normal" expressions */
 
-            AslGbl_FoldConstants = FALSE;
+            Gbl_FoldConstants = FALSE;
             break;
 
         case 'i':
 
             /* Disable integer optimization to constants */
 
-            AslGbl_IntegerOptimizationFlag = FALSE;
+            Gbl_IntegerOptimizationFlag = FALSE;
             break;
 
         case 'n':
 
             /* Disable named reference optimization */
 
-            AslGbl_ReferenceOptimizationFlag = FALSE;
+            Gbl_ReferenceOptimizationFlag = FALSE;
             break;
 
         case 't':
 
             /* Disable heavy typechecking */
 
-            AslGbl_DoTypechecking = FALSE;
+            Gbl_DoTypechecking = FALSE;
             break;
 
         default:
@@ -752,13 +752,13 @@ AslDoOptions (
         {
         case '^':   /* Proprocess only, emit (.i) file */
 
-            AslGbl_PreprocessOnly = TRUE;
-            AslGbl_PreprocessorOutputFlag = TRUE;
+            Gbl_PreprocessOnly = TRUE;
+            Gbl_PreprocessorOutputFlag = TRUE;
             break;
 
         case 'n':   /* Disable preprocessor */
 
-            AslGbl_PreprocessFlag = FALSE;
+            Gbl_PreprocessFlag = FALSE;
             break;
 
         default:
@@ -770,25 +770,25 @@ AslDoOptions (
 
     case 'p':   /* Override default AML output filename */
 
-        AslGbl_OutputFilenamePrefix = AcpiGbl_Optarg;
-        UtConvertBackslashes (AslGbl_OutputFilenamePrefix);
-        AslGbl_UseDefaultAmlFilename = FALSE;
+        Gbl_OutputFilenamePrefix = AcpiGbl_Optarg;
+        UtConvertBackslashes (Gbl_OutputFilenamePrefix);
+        Gbl_UseDefaultAmlFilename = FALSE;
         break;
 
     case 'q':   /* ASL/ASl+ converter: compile only and leave badaml. */
 
         printf ("Convert ASL to ASL+ with comments\n");
-        AslGbl_FoldConstants = FALSE;
-        AslGbl_IntegerOptimizationFlag = FALSE;
-        AslGbl_ReferenceOptimizationFlag = FALSE;
-        AslGbl_OptimizeTrivialParseNodes = FALSE;
-        AslGbl_DoExternalsInPlace = TRUE;
+        Gbl_FoldConstants = FALSE;
+        Gbl_IntegerOptimizationFlag = FALSE;
+        Gbl_ReferenceOptimizationFlag = FALSE;
+        Gbl_OptimizeTrivialParseNodes = FALSE;
+        Gbl_DoExternalsInPlace = TRUE;
         AcpiGbl_CaptureComments = TRUE;
         return (0);
 
     case 'r':   /* Override revision found in table header */
 
-        AslGbl_RevisionOverride = (UINT8) strtoul (AcpiGbl_Optarg, NULL, 0);
+        Gbl_RevisionOverride = (UINT8) strtoul (AcpiGbl_Optarg, NULL, 0);
         break;
 
     case 's':   /* Create AML in a source code file */
@@ -799,21 +799,21 @@ AslDoOptions (
 
             /* Produce assembly code output file */
 
-            AslGbl_AsmOutputFlag = TRUE;
+            Gbl_AsmOutputFlag = TRUE;
             break;
 
         case 'c':
 
             /* Produce C hex output file */
 
-            AslGbl_C_OutputFlag = TRUE;
+            Gbl_C_OutputFlag = TRUE;
             break;
 
         case 'o':
 
             /* Produce AML offset table in C */
 
-            AslGbl_C_OffsetTableFlag = TRUE;
+            Gbl_C_OffsetTableFlag = TRUE;
             break;
 
         default:
@@ -829,22 +829,17 @@ AslDoOptions (
         {
         case 'a':
 
-            AslGbl_HexOutputFlag = HEX_OUTPUT_ASM;
+            Gbl_HexOutputFlag = HEX_OUTPUT_ASM;
             break;
 
         case 'c':
 
-            AslGbl_HexOutputFlag = HEX_OUTPUT_C;
-            break;
-
-    case 'p': /* data table flex/bison prototype */
-
-            AslGbl_DtLexBisonPrototype = TRUE;
+            Gbl_HexOutputFlag = HEX_OUTPUT_C;
             break;
 
         case 's':
 
-            AslGbl_HexOutputFlag = HEX_OUTPUT_ASL;
+            Gbl_HexOutputFlag = HEX_OUTPUT_ASL;
             break;
 
         default:
@@ -856,7 +851,7 @@ AslDoOptions (
 
     case 'T':   /* Create a ACPI table template file */
 
-        AslGbl_DoTemplates = TRUE;
+        Gbl_DoTemplates = TRUE;
         break;
 
     case 'v':   /* Version and verbosity settings */
@@ -872,7 +867,7 @@ AslDoOptions (
 
             /* Disable all error/warning/remark messages */
 
-            AslGbl_NoErrors = TRUE;
+            Gbl_NoErrors = TRUE;
             break;
 
         case 'd':
@@ -885,8 +880,8 @@ AslDoOptions (
 
             /* Disable all warning/remark messages (errors only) */
 
-            AslGbl_DisplayRemarks = FALSE;
-            AslGbl_DisplayWarnings = FALSE;
+            Gbl_DisplayRemarks = FALSE;
+            Gbl_DisplayWarnings = FALSE;
             break;
 
         case 'i':
@@ -899,28 +894,29 @@ AslDoOptions (
              * 4) Error/warning messages are formatted appropriately to
              *    be recognized by MS Visual Studio
              */
-            AslGbl_VerboseErrors = FALSE;
-            AslGbl_DoSignon = FALSE;
+            Gbl_VerboseErrors = FALSE;
+            Gbl_DoSignon = FALSE;
+            Gbl_Files[ASL_FILE_STDERR].Handle = stdout;
             break;
 
         case 'o':
 
-            AslGbl_DisplayOptimizations = TRUE;
+            Gbl_DisplayOptimizations = TRUE;
             break;
 
         case 'r':
 
-            AslGbl_DisplayRemarks = FALSE;
+            Gbl_DisplayRemarks = FALSE;
             break;
 
         case 's':
 
-            AslGbl_DoSignon = FALSE;
+            Gbl_DoSignon = FALSE;
             break;
 
         case 't':
 
-            AslGbl_VerboseTemplates = TRUE;
+            Gbl_VerboseTemplates = TRUE;
             break;
 
         case 'w':
@@ -968,41 +964,24 @@ AslDoOptions (
         {
         case '1':
 
-            AslGbl_WarningLevel = ASL_WARNING;
+            Gbl_WarningLevel = ASL_WARNING;
             break;
 
         case '2':
 
-            AslGbl_WarningLevel = ASL_WARNING2;
+            Gbl_WarningLevel = ASL_WARNING2;
             break;
 
         case '3':
 
-            AslGbl_WarningLevel = ASL_WARNING3;
+            Gbl_WarningLevel = ASL_WARNING3;
             break;
 
         case 'e':
 
-            AslGbl_WarningsAsErrors = TRUE;
+            Gbl_WarningsAsErrors = TRUE;
             break;
 
-        case 'w':
-
-            /* Get the required argument */
-
-            if (AcpiGetoptArgument (argc, argv))
-            {
-                return (-1);
-            }
-
-            Status = AslElevateException (AcpiGbl_Optarg);
-            if (ACPI_FAILURE (Status))
-            {
-                return (-1);
-            }
-            break;
-
-
         default:
 
             printf ("Unknown option: -w%s\n", AcpiGbl_Optarg);
@@ -1017,7 +996,7 @@ AslDoOptions (
 
     case 'z':
 
-        AslGbl_UseOriginalCompilerId = TRUE;
+        Gbl_UseOriginalCompilerId = TRUE;
         break;
 
     default:
@@ -1077,7 +1056,7 @@ static int
 AslDoResponseFile (
     char                    *Filename)
 {
-    char                    *argv = AslGbl_StringBuffer2;
+    char                    *argv = StringBuffer2;
     FILE                    *ResponseFile;
     int                     OptStatus = 0;
     int                     Opterr;
@@ -1101,11 +1080,11 @@ AslDoResponseFile (
      * Process all lines in the response file. There must be one complete
      * option per line
      */
-    while (fgets (AslGbl_StringBuffer, ASL_STRING_BUFFER_SIZE, ResponseFile))
+    while (fgets (StringBuffer, ASL_MSG_BUFFER_SIZE, ResponseFile))
     {
         /* Compress all tokens, allowing us to use a single argv entry */
 
-        AslMergeOptionTokens (AslGbl_StringBuffer, AslGbl_StringBuffer2);
+        AslMergeOptionTokens (StringBuffer, StringBuffer2);
 
         /* Process the option */
 
@@ -1116,7 +1095,7 @@ AslDoResponseFile (
         if (OptStatus)
         {
             printf ("Invalid option in command file %s: %s\n",
-                Filename, AslGbl_StringBuffer);
+                Filename, StringBuffer);
             break;
         }
     }
