@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2019, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2017, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -201,7 +201,7 @@ DtError (
             FieldObject->Line,
             FieldObject->ByteOffset,
             FieldObject->Column,
-            AslGbl_Files[ASL_FILE_INPUT].Filename, ExtraMessage);
+            Gbl_Files[ASL_FILE_INPUT].Filename, ExtraMessage);
     }
     else
     {
@@ -239,7 +239,7 @@ DtNameError (
     case ASL_WARNING2:
     case ASL_WARNING3:
 
-        if (AslGbl_WarningLevel < Level)
+        if (Gbl_WarningLevel < Level)
         {
             return;
         }
@@ -257,7 +257,7 @@ DtNameError (
             FieldObject->Line,
             FieldObject->ByteOffset,
             FieldObject->NameColumn,
-            AslGbl_Files[ASL_FILE_INPUT].Filename, ExtraMessage);
+            Gbl_Files[ASL_FILE_INPUT].Filename, ExtraMessage);
     }
     else
     {
@@ -640,8 +640,8 @@ DtGetFieldLength (
         else
         {   /* At this point, this is a fatal error */
 
-            sprintf (AslGbl_MsgBuffer, "Expected \"%s\"", Info->Name);
-            DtFatal (ASL_MSG_COMPILER_INTERNAL, NULL, AslGbl_MsgBuffer);
+            sprintf (MsgBuffer, "Expected \"%s\"", Info->Name);
+            DtFatal (ASL_MSG_COMPILER_INTERNAL, NULL, MsgBuffer);
             return (0);
         }
         break;
@@ -672,8 +672,8 @@ DtGetFieldLength (
         else
         {   /* At this point, this is a fatal error */
 
-            sprintf (AslGbl_MsgBuffer, "Expected \"%s\"", Info->Name);
-            DtFatal (ASL_MSG_COMPILER_INTERNAL, NULL, AslGbl_MsgBuffer);
+            sprintf (MsgBuffer, "Expected \"%s\"", Info->Name);
+            DtFatal (ASL_MSG_COMPILER_INTERNAL, NULL, MsgBuffer);
             return (0);
         }
         break;
@@ -768,7 +768,7 @@ DtSetTableChecksum (
     UINT8                   OldSum;
 
 
-    DtWalkTableTree (AslGbl_RootTable, DtSum, NULL, &Checksum);
+    DtWalkTableTree (Gbl_RootTable, DtSum, NULL, &Checksum);
 
     OldSum = *ChecksumPointer;
     Checksum = (UINT8) (Checksum - OldSum);
@@ -800,7 +800,7 @@ DtSetTableLength (
     DT_SUBTABLE             *ChildTable;
 
 
-    ParentTable = AslGbl_RootTable;
+    ParentTable = Gbl_RootTable;
     ChildTable = NULL;
 
     if (!ParentTable)
@@ -838,7 +838,7 @@ DtSetTableLength (
         {
             ChildTable = ParentTable;
 
-            if (ChildTable == AslGbl_RootTable)
+            if (ChildTable == Gbl_RootTable)
             {
                 break;
             }
@@ -907,7 +907,7 @@ DtWalkTableTree (
         else
         {
             ChildTable = ParentTable;
-            if (ChildTable == AslGbl_RootTable)
+            if (ChildTable == Gbl_RootTable)
             {
                 break;
             }
