@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2019, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2017, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -214,7 +214,7 @@ PrDoIncludeFile (
  * Supported preprocessor directives
  * Each entry is of the form "Name, ArgumentCount"
  */
-static const PR_DIRECTIVE_INFO      AslGbl_DirectiveInfo[] =
+static const PR_DIRECTIVE_INFO      Gbl_DirectiveInfo[] =
 {
     {"define",          1},
     {"elif",            0}, /* Converted to #else..#if internally */
@@ -275,7 +275,7 @@ PrInitializePreprocessor (
     /* Init globals and the list of #defines */
 
     PrInitializeGlobals ();
-    AslGbl_DefineList = NULL;
+    Gbl_DefineList = NULL;
 }
 
 
@@ -299,16 +299,16 @@ PrInitializeGlobals (
 {
     /* Init globals */
 
-    AslGbl_InputFileList = NULL;
-    AslGbl_CurrentLineNumber = 1;
-    AslGbl_PreprocessorLineNumber = 1;
-    AslGbl_PreprocessorError = FALSE;
+    Gbl_InputFileList = NULL;
+    Gbl_CurrentLineNumber = 1;
+    Gbl_PreprocessorLineNumber = 1;
+    Gbl_PreprocessorError = FALSE;
 
     /* These are used to track #if/#else blocks (possibly nested) */
 
-    AslGbl_IfDepth = 0;
-    AslGbl_IgnoringThisCodeBlock = FALSE;
-    AslGbl_DirectiveStack = NULL;
+    Gbl_IfDepth = 0;
+    Gbl_IgnoringThisCodeBlock = FALSE;
+    Gbl_DirectiveStack = NULL;
 }
 
 
@@ -337,10 +337,10 @@ PrTerminatePreprocessor (
      * The persistent defines (created on the command line) are always at the
      * end of the list. We save them.
      */
-    while ((AslGbl_DefineList) && (!AslGbl_DefineList->Persist))
+    while ((Gbl_DefineList) && (!Gbl_DefineList->Persist))
     {
-        DefineInfo = AslGbl_DefineList;
-        AslGbl_DefineList = DefineInfo->Next;
+        DefineInfo = Gbl_DefineList;
+        Gbl_DefineList = DefineInfo->Next;
 
         ACPI_FREE (DefineInfo->Replacement);
         ACPI_FREE (DefineInfo->Identifier);
@@ -388,15 +388,15 @@ PrDoPreprocess (
     /* Point compiler input to the new preprocessor output file (.pre) */
 
     FlCloseFile (ASL_FILE_INPUT);
-    AslGbl_Files[ASL_FILE_INPUT].Handle = AslGbl_Files[ASL_FILE_PREPROCESSOR].Handle;
-    AslCompilerin = AslGbl_Files[ASL_FILE_INPUT].Handle;
+    Gbl_Files[ASL_FILE_INPUT].Handle = Gbl_Files[ASL_FILE_PREPROCESSOR].Handle;
+    AslCompilerin = Gbl_Files[ASL_FILE_INPUT].Handle;
 
     /* Reset globals to allow compiler to run */
 
     FlSeekFile (ASL_FILE_INPUT, 0);
-    if (!AslGbl_PreprocessOnly)
+    if (!Gbl_PreprocessOnly)
     {
-        AslGbl_CurrentLineNumber = 0;
+        Gbl_CurrentLineNumber = 0;
     }
 
     DbgPrint (ASL_DEBUG_OUTPUT, "Preprocessing phase complete \n\n");
@@ -436,10 +436,10 @@ PrPreprocessInputFile (
 
     /* Scan source line-by-line and process directives. Then write the .i file */
 
-    while ((Status = PrGetNextLine (AslGbl_Files[ASL_FILE_INPUT].Handle)) != ASL_EOF)
+    while ((Status = PrGetNextLine (Gbl_Files[ASL_FILE_INPUT].Handle)) != ASL_EOF)
     {
-        AslGbl_CurrentLineNumber++;
-        AslGbl_LogicalLineNumber++;
+        Gbl_CurrentLineNumber++;
+        Gbl_LogicalLineNumber++;
 
         if (Status == ASL_IGNORE_LINE)
         {
@@ -448,8 +448,8 @@ PrPreprocessInputFile (
 
         /* Need a copy of the input line for strok() */
 
-        strcpy (AslGbl_MainTokenBuffer, AslGbl_CurrentLineBuffer);
-        Token = PrGetNextToken (AslGbl_MainTokenBuffer, PR_TOKEN_SEPARATORS, &Next);
+        strcpy (Gbl_MainTokenBuffer, Gbl_CurrentLineBuffer);
+        Token = PrGetNextToken (Gbl_MainTokenBuffer, PR_TOKEN_SEPARATORS, &Next);
         OffsetAdjust = 0;
 
         /* All preprocessor directives must begin with '#' */
@@ -476,7 +476,7 @@ PrPreprocessInputFile (
          * FALSE, ignore the line and do not write it to the output file.
          * This continues until an #else or #endif is encountered.
          */
-        if (AslGbl_IgnoringThisCodeBlock)
+        if (Gbl_IgnoringThisCodeBlock)
         {
             continue;
         }
@@ -494,10 +494,10 @@ PrPreprocessInputFile (
 
                     DbgPrint (ASL_DEBUG_OUTPUT, PR_PREFIX_ID
                         "Matched Macro: %s->%s\n",
-                        AslGbl_CurrentLineNumber, DefineInfo->Identifier,
+                        Gbl_CurrentLineNumber, DefineInfo->Identifier,
                         DefineInfo->Replacement);
 
-                    PrDoMacroInvocation (AslGbl_MainTokenBuffer, Token,
+                    PrDoMacroInvocation (Gbl_MainTokenBuffer, Token,
                         DefineInfo, &Next);
                 }
                 else
@@ -506,9 +506,9 @@ PrPreprocessInputFile (
 
                     /* Replace the name in the original line buffer */
 
-                    TokenOffset = Token - AslGbl_MainTokenBuffer + OffsetAdjust;
+                    TokenOffset = Token - Gbl_MainTokenBuffer + OffsetAdjust;
                     PrReplaceData (
-                        &AslGbl_CurrentLineBuffer[TokenOffset], strlen (Token),
+                        &Gbl_CurrentLineBuffer[TokenOffset], strlen (Token),
                         ReplaceString, strlen (ReplaceString));
 
                     /* Adjust for length difference between old and new name length */
@@ -517,7 +517,7 @@ PrPreprocessInputFile (
 
                     DbgPrint (ASL_DEBUG_OUTPUT, PR_PREFIX_ID
                         "Matched #define: %s->%s\n",
-                        AslGbl_CurrentLineNumber, Token,
+                        Gbl_CurrentLineNumber, Token,
                         *ReplaceString ? ReplaceString : "(NULL STRING)");
                 }
             }
@@ -525,7 +525,7 @@ PrPreprocessInputFile (
             Token = PrGetNextToken (NULL, PR_TOKEN_SEPARATORS, &Next);
         }
 
-        AslGbl_PreprocessorLineNumber++;
+        Gbl_PreprocessorLineNumber++;
 
 
 WriteEntireLine:
@@ -533,8 +533,8 @@ WriteEntireLine:
          * Now we can write the possibly modified source line to the
          * preprocessor file(s).
          */
-        FlWriteFile (ASL_FILE_PREPROCESSOR, AslGbl_CurrentLineBuffer,
-            strlen (AslGbl_CurrentLineBuffer));
+        FlWriteFile (ASL_FILE_PREPROCESSOR, Gbl_CurrentLineBuffer,
+            strlen (Gbl_CurrentLineBuffer));
     }
 }
 
@@ -557,7 +557,7 @@ PrDoDirective (
     char                    *DirectiveToken,
     char                    **Next)
 {
-    char                    *Token = AslGbl_MainTokenBuffer;
+    char                    *Token = Gbl_MainTokenBuffer;
     char                    *Token2 = NULL;
     char                    *End;
     UINT64                  Value;
@@ -579,7 +579,7 @@ PrDoDirective (
 
         DbgPrint (ASL_PARSE_OUTPUT, PR_PREFIX_ID
             "#%s: Unknown directive\n",
-            AslGbl_CurrentLineNumber, DirectiveToken);
+            Gbl_CurrentLineNumber, DirectiveToken);
         return;
     }
 
@@ -590,25 +590,25 @@ PrDoDirective (
      * original source file.
      */
     FlPrintFile (ASL_FILE_PREPROCESSOR, "#line %u \"%s\" // #%s\n",
-        AslGbl_CurrentLineNumber, AslGbl_Files[ASL_FILE_INPUT].Filename,
-        AslGbl_DirectiveInfo[Directive].Name);
+        Gbl_CurrentLineNumber, Gbl_Files[ASL_FILE_INPUT].Filename,
+        Gbl_DirectiveInfo[Directive].Name);
 
     /*
      * If we are currently ignoring this block and we encounter a #else or
      * #elif, we must ignore their blocks also if the parent block is also
      * being ignored.
      */
-    if (AslGbl_IgnoringThisCodeBlock)
+    if (Gbl_IgnoringThisCodeBlock)
     {
         switch (Directive)
         {
         case PR_DIRECTIVE_ELSE:
         case PR_DIRECTIVE_ELIF:
 
-            if (AslGbl_DirectiveStack &&
-                AslGbl_DirectiveStack->IgnoringThisCodeBlock)
+            if (Gbl_DirectiveStack &&
+                Gbl_DirectiveStack->IgnoringThisCodeBlock)
             {
-                PrDbgPrint ("Ignoring", AslGbl_DirectiveInfo[Directive].Name);
+                PrDbgPrint ("Ignoring", Gbl_DirectiveInfo[Directive].Name);
                 return;
             }
             break;
@@ -627,16 +627,16 @@ PrDoDirective (
     {
     case PR_DIRECTIVE_ELSE:
 
-        AslGbl_IgnoringThisCodeBlock = !(AslGbl_IgnoringThisCodeBlock);
+        Gbl_IgnoringThisCodeBlock = !(Gbl_IgnoringThisCodeBlock);
         PrDbgPrint ("Executing", "else block");
         return;
 
     case PR_DIRECTIVE_ELIF:
 
-        AslGbl_IgnoringThisCodeBlock = !(AslGbl_IgnoringThisCodeBlock);
+        Gbl_IgnoringThisCodeBlock = !(Gbl_IgnoringThisCodeBlock);
         Directive = PR_DIRECTIVE_IF;
 
-        if (AslGbl_IgnoringThisCodeBlock == TRUE)
+        if (Gbl_IgnoringThisCodeBlock == TRUE)
         {
             /* Not executing the ELSE part -- all done here */
             PrDbgPrint ("Ignoring", "elif block");
@@ -675,7 +675,7 @@ PrDoDirective (
 
     /* Most directives have at least one argument */
 
-    if (AslGbl_DirectiveInfo[Directive].ArgCount >= 1)
+    if (Gbl_DirectiveInfo[Directive].ArgCount >= 1)
     {
         Token = PrGetNextToken (NULL, PR_TOKEN_SEPARATORS, Next);
         if (!Token)
@@ -684,7 +684,7 @@ PrDoDirective (
         }
     }
 
-    if (AslGbl_DirectiveInfo[Directive].ArgCount >= 2)
+    if (Gbl_DirectiveInfo[Directive].ArgCount >= 2)
     {
         Token2 = PrGetNextToken (NULL, PR_TOKEN_SEPARATORS, Next);
         if (!Token2)
@@ -699,7 +699,7 @@ PrDoDirective (
      * For "if" style directives, open/push a new block anyway. We
      * must do this to keep track of #endif directives
      */
-    if (AslGbl_IgnoringThisCodeBlock)
+    if (Gbl_IgnoringThisCodeBlock)
     {
         switch (Directive)
         {
@@ -708,7 +708,7 @@ PrDoDirective (
         case PR_DIRECTIVE_IFNDEF:
 
             PrPushDirective (Directive, Token);
-            PrDbgPrint ("Ignoring", AslGbl_DirectiveInfo[Directive].Name);
+            PrDbgPrint ("Ignoring", Gbl_DirectiveInfo[Directive].Name);
             break;
 
         default:
@@ -721,18 +721,18 @@ PrDoDirective (
     /*
      * Execute the directive
      */
-    PrDbgPrint ("Begin execution", AslGbl_DirectiveInfo[Directive].Name);
+    PrDbgPrint ("Begin execution", Gbl_DirectiveInfo[Directive].Name);
 
     switch (Directive)
     {
     case PR_DIRECTIVE_IF:
 
-        TokenOffset = Token - AslGbl_MainTokenBuffer;
+        TokenOffset = Token - Gbl_MainTokenBuffer;
 
         /* Need to expand #define macros in the expression string first */
 
         Status = PrResolveIntegerExpression (
-            &AslGbl_CurrentLineBuffer[TokenOffset-1], &Value);
+            &Gbl_CurrentLineBuffer[TokenOffset-1], &Value);
         if (ACPI_FAILURE (Status))
         {
             return;
@@ -741,13 +741,13 @@ PrDoDirective (
         PrPushDirective (Directive, Token);
         if (!Value)
         {
-            AslGbl_IgnoringThisCodeBlock = TRUE;
+            Gbl_IgnoringThisCodeBlock = TRUE;
         }
 
         DbgPrint (ASL_PARSE_OUTPUT, PR_PREFIX_ID
             "Resolved #if: %8.8X%8.8X %s\n",
-            AslGbl_CurrentLineNumber, ACPI_FORMAT_UINT64 (Value),
-            AslGbl_IgnoringThisCodeBlock ? "<Skipping Block>" : "<Executing Block>");
+            Gbl_CurrentLineNumber, ACPI_FORMAT_UINT64 (Value),
+            Gbl_IgnoringThisCodeBlock ? "<Skipping Block>" : "<Executing Block>");
         break;
 
     case PR_DIRECTIVE_IFDEF:
@@ -755,7 +755,7 @@ PrDoDirective (
         PrPushDirective (Directive, Token);
         if (!PrMatchDefine (Token))
         {
-            AslGbl_IgnoringThisCodeBlock = TRUE;
+            Gbl_IgnoringThisCodeBlock = TRUE;
         }
 
         PrDbgPrint ("Evaluated", "ifdef");
@@ -766,7 +766,7 @@ PrDoDirective (
         PrPushDirective (Directive, Token);
         if (PrMatchDefine (Token))
         {
-            AslGbl_IgnoringThisCodeBlock = TRUE;
+            Gbl_IgnoringThisCodeBlock = TRUE;
         }
 
         PrDbgPrint ("Evaluated", "ifndef");
@@ -777,13 +777,13 @@ PrDoDirective (
          * By definition, if first char after the name is a paren,
          * this is a function macro.
          */
-        TokenOffset = Token - AslGbl_MainTokenBuffer + strlen (Token);
-        if (*(&AslGbl_CurrentLineBuffer[TokenOffset]) == '(')
+        TokenOffset = Token - Gbl_MainTokenBuffer + strlen (Token);
+        if (*(&Gbl_CurrentLineBuffer[TokenOffset]) == '(')
         {
 #ifndef MACROS_SUPPORTED
             AcpiOsPrintf (
                 "%s ERROR - line %u: #define macros are not supported yet\n",
-                AslGbl_CurrentLineBuffer, AslGbl_LogicalLineNumber);
+                Gbl_CurrentLineBuffer, Gbl_LogicalLineNumber);
             exit(1);
 #else
             PrAddMacro (Token, Next);
@@ -822,7 +822,7 @@ PrDoDirective (
 #endif
             DbgPrint (ASL_PARSE_OUTPUT, PR_PREFIX_ID
                 "New #define: %s->%s\n",
-                AslGbl_LogicalLineNumber, Token, Token2);
+                Gbl_LogicalLineNumber, Token, Token2);
 
             PrAddDefine (Token, Token2, FALSE);
         }
@@ -835,8 +835,8 @@ PrDoDirective (
         PrError (ASL_ERROR, ASL_MSG_ERROR_DIRECTIVE,
             THIS_TOKEN_OFFSET (Token));
 
-        AslGbl_SourceLine = 0;
-        AslGbl_NextError = AslGbl_ErrorLog;
+        Gbl_SourceLine = 0;
+        Gbl_NextError = Gbl_ErrorLog;
         CmCleanupAndExit ();
         exit(1);
 
@@ -849,8 +849,8 @@ PrDoDirective (
         }
 
         DbgPrint (ASL_PARSE_OUTPUT, PR_PREFIX_ID
-            "Start #include file \"%s\"\n", AslGbl_CurrentLineNumber,
-            Token);
+            "Start #include file \"%s\"\n", Gbl_CurrentLineNumber,
+            Token, Gbl_CurrentLineNumber);
 
         PrDoIncludeFile (Token);
         break;
@@ -871,32 +871,32 @@ PrDoDirective (
 
         DbgPrint (ASL_PARSE_OUTPUT, PR_PREFIX_ID
             "Start #includebuffer input from file \"%s\", buffer name %s\n",
-            AslGbl_CurrentLineNumber, Token, Token2);
+            Gbl_CurrentLineNumber, Token, Token2);
 
         PrDoIncludeBuffer (Token, Token2);
         break;
 
     case PR_DIRECTIVE_LINE:
 
-        TokenOffset = Token - AslGbl_MainTokenBuffer;
+        TokenOffset = Token - Gbl_MainTokenBuffer;
 
         Status = PrResolveIntegerExpression (
-            &AslGbl_CurrentLineBuffer[TokenOffset-1], &Value);
+            &Gbl_CurrentLineBuffer[TokenOffset-1], &Value);
         if (ACPI_FAILURE (Status))
         {
             return;
         }
 
         DbgPrint (ASL_PARSE_OUTPUT, PR_PREFIX_ID
-            "User #line invocation %s\n", AslGbl_CurrentLineNumber,
+            "User #line invocation %s\n", Gbl_CurrentLineNumber,
             Token);
 
-        AslGbl_CurrentLineNumber = (UINT32) Value;
+        Gbl_CurrentLineNumber = (UINT32) Value;
 
         /* Emit #line into the preprocessor file */
 
         FlPrintFile (ASL_FILE_PREPROCESSOR, "#line %u \"%s\"\n",
-            AslGbl_CurrentLineNumber, AslGbl_Files[ASL_FILE_INPUT].Filename);
+            Gbl_CurrentLineNumber, Gbl_Files[ASL_FILE_INPUT].Filename);
         break;
 
     case PR_DIRECTIVE_PRAGMA:
@@ -909,8 +909,8 @@ PrDoDirective (
                 goto SyntaxError;
             }
 
-            TokenOffset = Token - AslGbl_MainTokenBuffer;
-            AslDisableException (&AslGbl_CurrentLineBuffer[TokenOffset]);
+            TokenOffset = Token - Gbl_MainTokenBuffer;
+            AslDisableException (&Gbl_CurrentLineBuffer[TokenOffset]);
         }
         else if (!strcmp (Token, "message"))
         {
@@ -920,8 +920,8 @@ PrDoDirective (
                 goto SyntaxError;
             }
 
-            TokenOffset = Token - AslGbl_MainTokenBuffer;
-            AcpiOsPrintf ("%s\n", &AslGbl_CurrentLineBuffer[TokenOffset]);
+            TokenOffset = Token - Gbl_MainTokenBuffer;
+            AcpiOsPrintf ("%s\n", &Gbl_CurrentLineBuffer[TokenOffset]);
         }
         else
         {
@@ -935,7 +935,7 @@ PrDoDirective (
     case PR_DIRECTIVE_UNDEF:
 
         DbgPrint (ASL_PARSE_OUTPUT, PR_PREFIX_ID
-            "#undef: %s\n", AslGbl_CurrentLineNumber, Token);
+            "#undef: %s\n", Gbl_CurrentLineNumber, Token);
 
         PrRemoveDefine (Token);
         break;
@@ -945,8 +945,8 @@ PrDoDirective (
         PrError (ASL_WARNING, ASL_MSG_WARNING_DIRECTIVE,
             THIS_TOKEN_OFFSET (Token));
 
-        AslGbl_SourceLine = 0;
-        AslGbl_NextError = AslGbl_ErrorLog;
+        Gbl_SourceLine = 0;
+        Gbl_NextError = Gbl_ErrorLog;
         break;
 
     default:
@@ -954,7 +954,7 @@ PrDoDirective (
         /* Should never get here */
         DbgPrint (ASL_PARSE_OUTPUT, PR_PREFIX_ID
             "Unrecognized directive: %u\n",
-            AslGbl_CurrentLineNumber, Directive);
+            Gbl_CurrentLineNumber, Directive);
         break;
     }
 
@@ -1010,14 +1010,14 @@ PrGetNextLine (
 
     /* Always clear the global line buffer */
 
-    memset (AslGbl_CurrentLineBuffer, 0, AslGbl_LineBufferSize);
+    memset (Gbl_CurrentLineBuffer, 0, Gbl_LineBufferSize);
     for (i = 0; ;)
     {
         /*
          * If line is too long, expand the line buffers. Also increases
-         * AslGbl_LineBufferSize.
+         * Gbl_LineBufferSize.
          */
-        if (i >= AslGbl_LineBufferSize)
+        if (i >= Gbl_LineBufferSize)
         {
             UtExpandLineBuffers ();
         }
@@ -1033,7 +1033,7 @@ PrGetNextLine (
              */
             if (i > 0)
             {
-                AslGbl_CurrentLineBuffer[i] = '\n';
+                Gbl_CurrentLineBuffer[i] = '\n';
                 return (AE_OK);
             }
 
@@ -1093,7 +1093,7 @@ PrGetNextLine (
 
         /* Always copy the character into line buffer */
 
-        AslGbl_CurrentLineBuffer[i] = (char) c;
+        Gbl_CurrentLineBuffer[i] = (char) c;
         i++;
 
         /* Always exit on end-of-line */
@@ -1152,9 +1152,9 @@ PrMatchDirective (
         return (ASL_DIRECTIVE_NOT_FOUND);
     }
 
-    for (i = 0; AslGbl_DirectiveInfo[i].Name; i++)
+    for (i = 0; Gbl_DirectiveInfo[i].Name; i++)
     {
-        if (!strcmp (AslGbl_DirectiveInfo[i].Name, Directive))
+        if (!strcmp (Gbl_DirectiveInfo[i].Name, Directive))
         {
             return (i);
         }
@@ -1191,26 +1191,25 @@ PrPushDirective (
 
     /* Allocate and populate a stack info item */
 
-    Info = ACPI_CAST_PTR (DIRECTIVE_INFO,
-        UtLocalCacheCalloc (sizeof (DIRECTIVE_INFO)));
+    Info = ACPI_ALLOCATE (sizeof (DIRECTIVE_INFO));
 
-    Info->Next = AslGbl_DirectiveStack;
+    Info->Next = Gbl_DirectiveStack;
     Info->Directive = Directive;
-    Info->IgnoringThisCodeBlock = AslGbl_IgnoringThisCodeBlock;
+    Info->IgnoringThisCodeBlock = Gbl_IgnoringThisCodeBlock;
     AcpiUtSafeStrncpy (Info->Argument, Argument, MAX_ARGUMENT_LENGTH);
 
     DbgPrint (ASL_DEBUG_OUTPUT,
         "Pr(%.4u) - [%u %s] %*s Pushed [#%s %s]: IgnoreFlag = %s\n",
-        AslGbl_CurrentLineNumber, AslGbl_IfDepth,
-        AslGbl_IgnoringThisCodeBlock ? "I" : "E",
-        AslGbl_IfDepth * 4, " ",
-        AslGbl_DirectiveInfo[Directive].Name,
-        Argument, AslGbl_IgnoringThisCodeBlock ? "TRUE" : "FALSE");
+        Gbl_CurrentLineNumber, Gbl_IfDepth,
+        Gbl_IgnoringThisCodeBlock ? "I" : "E",
+        Gbl_IfDepth * 4, " ",
+        Gbl_DirectiveInfo[Directive].Name,
+        Argument, Gbl_IgnoringThisCodeBlock ? "TRUE" : "FALSE");
 
     /* Push new item */
 
-    AslGbl_DirectiveStack = Info;
-    AslGbl_IfDepth++;
+    Gbl_DirectiveStack = Info;
+    Gbl_IfDepth++;
 }
 
 
@@ -1239,7 +1238,7 @@ PrPopDirective (
 
     /* Check for empty stack */
 
-    Info = AslGbl_DirectiveStack;
+    Info = Gbl_DirectiveStack;
     if (!Info)
     {
         return (AE_ERROR);
@@ -1247,18 +1246,19 @@ PrPopDirective (
 
     /* Pop one item, keep globals up-to-date */
 
-    AslGbl_IfDepth--;
-    AslGbl_IgnoringThisCodeBlock = Info->IgnoringThisCodeBlock;
-    AslGbl_DirectiveStack = Info->Next;
+    Gbl_IfDepth--;
+    Gbl_IgnoringThisCodeBlock = Info->IgnoringThisCodeBlock;
+    Gbl_DirectiveStack = Info->Next;
 
     DbgPrint (ASL_DEBUG_OUTPUT,
         "Pr(%.4u) - [%u %s] %*s Popped [#%s %s]: IgnoreFlag now = %s\n",
-        AslGbl_CurrentLineNumber, AslGbl_IfDepth,
-        AslGbl_IgnoringThisCodeBlock ? "I" : "E",
-        AslGbl_IfDepth * 4, " ",
-        AslGbl_DirectiveInfo[Info->Directive].Name,
-        Info->Argument, AslGbl_IgnoringThisCodeBlock ? "TRUE" : "FALSE");
+        Gbl_CurrentLineNumber, Gbl_IfDepth,
+        Gbl_IgnoringThisCodeBlock ? "I" : "E",
+        Gbl_IfDepth * 4, " ",
+        Gbl_DirectiveInfo[Info->Directive].Name,
+        Info->Argument, Gbl_IgnoringThisCodeBlock ? "TRUE" : "FALSE");
 
+    ACPI_FREE (Info);
     return (AE_OK);
 }
 
@@ -1284,10 +1284,10 @@ PrDbgPrint (
 
     DbgPrint (ASL_DEBUG_OUTPUT, "Pr(%.4u) - [%u %s] "
         "%*s %s #%s, IfDepth %u\n",
-        AslGbl_CurrentLineNumber, AslGbl_IfDepth,
-        AslGbl_IgnoringThisCodeBlock ? "I" : "E",
-        AslGbl_IfDepth * 4, " ",
-        Action, DirectiveName, AslGbl_IfDepth);
+        Gbl_CurrentLineNumber, Gbl_IfDepth,
+        Gbl_IgnoringThisCodeBlock ? "I" : "E",
+        Gbl_IfDepth * 4, " ",
+        Action, DirectiveName, Gbl_IfDepth);
 }
 
 
@@ -1356,7 +1356,7 @@ PrDoIncludeBuffer (
     {
         if (!(i % 8))
         {
-            FlPrintFile (ASL_FILE_PREPROCESSOR, "\n   ");
+            FlPrintFile (ASL_FILE_PREPROCESSOR, "\n   ", c);
         }
 
         FlPrintFile (ASL_FILE_PREPROCESSOR, " 0x%2.2X,", c);
@@ -1365,10 +1365,10 @@ PrDoIncludeBuffer (
 
     DbgPrint (ASL_PARSE_OUTPUT, PR_PREFIX_ID
         "#includebuffer: read %u bytes from %s\n",
-        AslGbl_CurrentLineNumber, i, FullPathname);
+        Gbl_CurrentLineNumber, i, FullPathname);
 
     /* Close the Name() operator */
 
-    FlPrintFile (ASL_FILE_PREPROCESSOR, "\n})\n");
+    FlPrintFile (ASL_FILE_PREPROCESSOR, "\n})\n", BufferName);
     fclose (BinaryBufferFile);
 }
