@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2019, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2017, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -157,10 +157,6 @@
 #include "acnamesp.h"
 #include "acparser.h"
 
-#ifdef ACPI_EXEC_APP
-#include "aecommon.h"
-#endif
-
 
 #define _COMPONENT          ACPI_DISPATCHER
         ACPI_MODULE_NAME    ("dsfield")
@@ -309,6 +305,7 @@ AcpiDsCreateBufferField (
     if (WalkState->DeferredNode)
     {
         Node = WalkState->DeferredNode;
+        Status = AE_OK;
     }
     else
     {
@@ -413,7 +410,7 @@ Cleanup:
  * FUNCTION:    AcpiDsGetFieldNames
  *
  * PARAMETERS:  Info            - CreateField info structure
- *              WalkState       - Current method state
+ *  `           WalkState       - Current method state
  *              Arg             - First parser arg for the field name list
  *
  * RETURN:      Status
@@ -433,12 +430,6 @@ AcpiDsGetFieldNames (
     UINT64                  Position;
     ACPI_PARSE_OBJECT       *Child;
 
-#ifdef ACPI_EXEC_APP
-    ACPI_OPERAND_OBJECT     *ResultDesc;
-    ACPI_OPERAND_OBJECT     *ObjDesc;
-    char                    *NamePath;
-#endif
-
 
     ACPI_FUNCTION_TRACE_PTR (DsGetFieldNames, Info);
 
@@ -573,17 +564,6 @@ AcpiDsGetFieldNames (
                     {
                         return_ACPI_STATUS (Status);
                     }
-#ifdef ACPI_EXEC_APP
-                    NamePath = AcpiNsGetExternalPathname (Info->FieldNode);
-                    if (ACPI_SUCCESS (AeLookupInitFileEntry (NamePath, &ObjDesc)))
-                    {
-                        AcpiExWriteDataToField (ObjDesc,
-                            AcpiNsGetAttachedObject (Info->FieldNode),
-                            &ResultDesc);
-                        AcpiUtRemoveReference (ObjDesc);
-                    }
-                    ACPI_FREE (NamePath);
-#endif
                 }
             }
 
@@ -682,12 +662,6 @@ AcpiDsCreateField (
     Info.RegionNode = RegionNode;
 
     Status = AcpiDsGetFieldNames (&Info, WalkState, Arg->Common.Next);
-    if (Info.RegionNode->Object->Region.SpaceId == ACPI_ADR_SPACE_PLATFORM_COMM &&
-        !(RegionNode->Object->Field.InternalPccBuffer
-        = ACPI_ALLOCATE_ZEROED(Info.RegionNode->Object->Region.Length)))
-    {
-        return_ACPI_STATUS (AE_NO_MEMORY);
-    }
     return_ACPI_STATUS (Status);
 }
 
@@ -782,9 +756,6 @@ AcpiDsInitFieldObjects (
         Flags |= ACPI_NS_TEMPORARY;
     }
 
-#ifdef ACPI_EXEC_APP
-        Flags |= ACPI_NS_OVERRIDE_IF_FOUND;
-#endif
     /*
      * Walk the list of entries in the FieldList
      * Note: FieldList can be of zero length. In this case, Arg will be NULL.
@@ -810,6 +781,8 @@ AcpiDsInitFieldObjects (
                 }
 
                 /* Name already exists, just ignore this error */
+
+                Status = AE_OK;
             }
 
             Arg->Common.Node = Node;
