@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2018, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2017, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -155,7 +155,6 @@
 #include "amlcode.h"
 #include "acdispat.h"
 #include "acinterp.h"
-#include "acparser.h"
 
 
 #define _COMPONENT          ACPI_NAMESPACE
@@ -209,7 +208,6 @@ AcpiDsBuildInternalPackageObj (
     ACPI_PARSE_OBJECT       *Parent;
     ACPI_OPERAND_OBJECT     *ObjDesc = NULL;
     ACPI_STATUS             Status = AE_OK;
-    BOOLEAN                 ModuleLevelCode = FALSE;
     UINT16                  ReferenceCount;
     UINT32                  Index;
     UINT32                  i;
@@ -218,13 +216,6 @@ AcpiDsBuildInternalPackageObj (
     ACPI_FUNCTION_TRACE (DsBuildInternalPackageObj);
 
 
-    /* Check if we are executing module level code */
-
-    if (WalkState->ParseFlags & ACPI_PARSE_MODULE_LEVEL)
-    {
-        ModuleLevelCode = TRUE;
-    }
-
     /* Find the parent of a possibly nested package */
 
     Parent = Op->Common.Parent;
@@ -259,43 +250,25 @@ AcpiDsBuildInternalPackageObj (
 
     /*
      * Allocate the element array (array of pointers to the individual
-     * objects) if necessary. the count is based on the NumElements
-     * parameter. Add an extra pointer slot so that the list is always
-     * null terminated.
+     * objects) based on the NumElements parameter. Add an extra pointer slot
+     * so that the list is always null terminated.
      */
+    ObjDesc->Package.Elements = ACPI_ALLOCATE_ZEROED (
+        ((ACPI_SIZE) ElementCount + 1) * sizeof (void *));
+
     if (!ObjDesc->Package.Elements)
     {
-        ObjDesc->Package.Elements = ACPI_ALLOCATE_ZEROED (
-            ((ACPI_SIZE) ElementCount + 1) * sizeof (void *));
-
-        if (!ObjDesc->Package.Elements)
-        {
-            AcpiUtDeleteObjectDesc (ObjDesc);
-            return_ACPI_STATUS (AE_NO_MEMORY);
-        }
-
-        ObjDesc->Package.Count = ElementCount;
+        AcpiUtDeleteObjectDesc (ObjDesc);
+        return_ACPI_STATUS (AE_NO_MEMORY);
     }
 
-    /* First arg is element count. Second arg begins the initializer list */
-
+    ObjDesc->Package.Count = ElementCount;
     Arg = Op->Common.Value.Arg;
     Arg = Arg->Common.Next;
 
-    /*
-     * If we are executing module-level code, we will defer the
-     * full resolution of the package elements in order to support
-     * forward references from the elements. This provides
-     * compatibility with other ACPI implementations.
-     */
-    if (ModuleLevelCode)
+    if (Arg)
     {
-        ObjDesc->Package.AmlStart = WalkState->Aml;
-        ObjDesc->Package.AmlLength = 0;
-
-        ACPI_DEBUG_PRINT_RAW ((ACPI_DB_PARSE,
-            "%s: Deferring resolution of Package elements\n",
-            ACPI_GET_FUNCTION_NAME));
+        ObjDesc->Package.Flags |= AOPOBJ_DATA_VALID;
     }
 
     /*
@@ -308,32 +281,6 @@ AcpiDsBuildInternalPackageObj (
     {
         if (Arg->Common.AmlOpcode == AML_INT_RETURN_VALUE_OP)
         {
-            if (!Arg->Common.Node)
-            {
-                /*
-                 * This is the case where an expression has returned a value.
-                 * The use of expressions (TermArgs) within individual
-                 * package elements is not supported by the AML interpreter,
-                 * even though the ASL grammar supports it. Example:
-                 *
-                 *      Name (INT1, 0x1234)
-                 *
-                 *      Name (PKG3, Package () {
-                 *          Add (INT1, 0xAAAA0000)
-                 *      })
-                 *
-                 *  1) No known AML interpreter supports this type of construct
-                 *  2) This fixes a fault if the construct is encountered
-                 */
-                ACPI_EXCEPTION ((AE_INFO, AE_SUPPORT,
-                    "Expressions within package elements are not supported"));
-
-                /* Cleanup the return object, it is not needed */
-
-                AcpiUtRemoveReference (WalkState->Results->Results.ObjDesc[0]);
-                return_ACPI_STATUS (AE_SUPPORT);
-            }
-
             if (Arg->Common.Node->Type == ACPI_TYPE_METHOD)
             {
                 /*
@@ -361,17 +308,12 @@ AcpiDsBuildInternalPackageObj (
                 ACPI_ERROR ((AE_INFO, "%-48s", "****DS namepath not found"));
             }
 
-            if (!ModuleLevelCode)
-            {
-                /*
-                 * Initialize this package element. This function handles the
-                 * resolution of named references within the package.
-                 * Forward references from module-level code are deferred
-                 * until all ACPI tables are loaded.
-                 */
-                AcpiDsInitPackageElement (0, ObjDesc->Package.Elements[i],
-                    NULL, &ObjDesc->Package.Elements[i]);
-            }
+            /*
+             * Initialize this package element. This function handles the
+             * resolution of named references within the package.
+             */
+            AcpiDsInitPackageElement (0, ObjDesc->Package.Elements[i],
+                NULL, &ObjDesc->Package.Elements[i]);
         }
 
         if (*ObjDescPtr)
@@ -441,21 +383,15 @@ AcpiDsBuildInternalPackageObj (
          * NumElements count.
          *
          * Note: this is not an error, the package is padded out
-         * with NULLs as per the ACPI specification.
+         * with NULLs.
          */
-        ACPI_DEBUG_PRINT_RAW ((ACPI_DB_INFO,
-            "%s: Package List length (%u) smaller than NumElements "
+        ACPI_DEBUG_PRINT ((ACPI_DB_INFO,
+            "Package List length (%u) smaller than NumElements "
             "count (%u), padded with null elements\n",
-            ACPI_GET_FUNCTION_NAME, i, ElementCount));
-    }
-
-    /* Module-level packages will be resolved later */
-
-    if (!ModuleLevelCode)
-    {
-        ObjDesc->Package.Flags |= AOPOBJ_DATA_VALID;
+            i, ElementCount));
     }
 
+    ObjDesc->Package.Flags |= AOPOBJ_DATA_VALID;
     Op->Common.Node = ACPI_CAST_PTR (ACPI_NAMESPACE_NODE, ObjDesc);
     return_ACPI_STATUS (Status);
 }
@@ -545,12 +481,11 @@ AcpiDsResolvePackageElement (
     ACPI_OPERAND_OBJECT     **ElementPtr)
 {
     ACPI_STATUS             Status;
-    ACPI_STATUS             Status2;
     ACPI_GENERIC_STATE      ScopeInfo;
     ACPI_OPERAND_OBJECT     *Element = *ElementPtr;
     ACPI_NAMESPACE_NODE     *ResolvedNode;
     ACPI_NAMESPACE_NODE     *OriginalNode;
-    char                    *ExternalPath = "";
+    char                    *ExternalPath = NULL;
     ACPI_OBJECT_TYPE        Type;
 
 
@@ -561,10 +496,6 @@ AcpiDsResolvePackageElement (
 
     if (Element->Reference.Resolved)
     {
-        ACPI_DEBUG_PRINT_RAW ((ACPI_DB_PARSE,
-            "%s: Package element is already resolved\n",
-            ACPI_GET_FUNCTION_NAME));
-
         return_VOID;
     }
 
@@ -572,47 +503,21 @@ AcpiDsResolvePackageElement (
 
     ScopeInfo.Scope.Node = Element->Reference.Node; /* Prefix node */
 
-    Status = AcpiNsLookup (&ScopeInfo, (char *) Element->Reference.Aml,
+    Status = AcpiNsLookup (&ScopeInfo,
+        (char *) Element->Reference.Aml,            /* Pointer to AML path */
         ACPI_TYPE_ANY, ACPI_IMODE_EXECUTE,
         ACPI_NS_SEARCH_PARENT | ACPI_NS_DONT_OPEN_SCOPE,
         NULL, &ResolvedNode);
     if (ACPI_FAILURE (Status))
     {
-        if ((Status == AE_NOT_FOUND) && AcpiGbl_IgnorePackageResolutionErrors)
-        {
-            /*
-             * Optionally be silent about the NOT_FOUND case for the referenced
-             * name. Although this is potentially a serious problem,
-             * it can generate a lot of noise/errors on platforms whose
-             * firmware carries around a bunch of unused Package objects.
-             * To disable these errors, set this global to TRUE:
-             *     AcpiGbl_IgnorePackageResolutionErrors
-             *
-             * If the AML actually tries to use such a package, the unresolved
-             * element(s) will be replaced with NULL elements.
-             */
-
-            /* Referenced name not found, set the element to NULL */
-
-            AcpiUtRemoveReference (*ElementPtr);
-            *ElementPtr = NULL;
-            return_VOID;
-        }
-
-        Status2 = AcpiNsExternalizeName (ACPI_UINT32_MAX,
-            (char *) Element->Reference.Aml, NULL, &ExternalPath);
+        Status = AcpiNsExternalizeName (ACPI_UINT32_MAX,
+            (char *) Element->Reference.Aml,
+            NULL, &ExternalPath);
 
         ACPI_EXCEPTION ((AE_INFO, Status,
-            "While resolving a named reference package element - %s",
-            ExternalPath));
-        if (ACPI_SUCCESS (Status2))
-        {
-            ACPI_FREE (ExternalPath);
-        }
+            "Could not find/resolve named package element: %s", ExternalPath));
 
-        /* Could not resolve name, set the element to NULL */
-
-        AcpiUtRemoveReference (*ElementPtr);
+        ACPI_FREE (ExternalPath);
         *ElementPtr = NULL;
         return_VOID;
     }
@@ -626,6 +531,24 @@ AcpiDsResolvePackageElement (
         *ElementPtr = NULL;
         return_VOID;
     }
+#if 0
+    else if (ResolvedNode->Flags & ANOBJ_TEMPORARY)
+    {
+        /*
+         * A temporary node found here indicates that the reference is
+         * to a node that was created within this method. We are not
+         * going to allow it (especially if the package is returned
+         * from the method) -- the temporary node will be deleted out
+         * from under the method. (05/2017).
+         */
+        ACPI_ERROR ((AE_INFO,
+            "Package element refers to a temporary name [%4.4s], "
+            "inserting a NULL element",
+            ResolvedNode->Name.Ascii));
+        *ElementPtr = NULL;
+        return_VOID;
+    }
+#endif
 
     /*
      * Special handling for Alias objects. We need ResolvedNode to point
@@ -664,6 +587,22 @@ AcpiDsResolvePackageElement (
         return_VOID;
     }
 
+#if 0
+/* TBD - alias support */
+    /*
+     * Special handling for Alias objects. We need to setup the type
+     * and the Op->Common.Node to point to the Alias target. Note,
+     * Alias has at most one level of indirection internally.
+     */
+    Type = Op->Common.Node->Type;
+    if (Type == ACPI_TYPE_LOCAL_ALIAS)
+    {
+        Type = ObjDesc->Common.Type;
+        Op->Common.Node = ACPI_CAST_PTR (ACPI_NAMESPACE_NODE,
+            Op->Common.Node->Object);
+    }
+#endif
+
     switch (Type)
     {
     /*
