@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2019, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2017, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -807,15 +807,6 @@ AcpiUtDumpAllocations (
                         Descriptor, Element->Size, Element->Module,
                         Element->Line, AcpiUtGetDescriptorName (Descriptor));
 
-                    /* Optional object hex dump */
-
-                    if (AcpiGbl_VerboseLeakDump)
-                    {
-                        AcpiOsPrintf ("\n");
-                        AcpiUtDumpBuffer ((UINT8 *) Descriptor, Element->Size,
-                            DB_BYTE_DISPLAY, 0);
-                    }
-
                     /* Validate the descriptor type using Type field and length */
 
                     DescriptorType = 0; /* Not a valid descriptor type */
@@ -864,7 +855,7 @@ AcpiUtDumpAllocations (
 
                     case ACPI_DESC_TYPE_PARSER:
 
-                        AcpiOsPrintf ("AmlOpcode 0x%04X\n",
+                        AcpiOsPrintf ("AmlOpcode 0x%04hX\n",
                             Descriptor->Op.Asl.AmlOpcode);
                         break;
 
