@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2019, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2017, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -281,7 +281,7 @@ extern const AH_ASL_OPERATOR        Gbl_AslOperatorInfo[];
 extern const AH_ASL_KEYWORD         Gbl_AslKeywordInfo[];
 extern const AH_UUID                Gbl_AcpiUuids[];
 extern const AH_DIRECTIVE_INFO      Gbl_PreprocessorDirectives[];
-extern const AH_TABLE               AcpiGbl_SupportedTables[];
+extern const AH_TABLE               Gbl_AcpiSupportedTables[];
 
 
 void
