@@ -1,6 +1,7 @@
 /******************************************************************************
  *
- * Module Name: ahaslkey - Table of all known ASL non-operator keywords
+ * Module Name: ahaslkey - Table of all known ASL non-operator keywords and
+ *                         table of iASL Preprocessor directives
  *
  *****************************************************************************/
 
@@ -8,13 +9,13 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2011, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2017, Intel Corp.
  * All rights reserved.
  *
  * 2. License
  *
  * 2.1. This is your license from Intel Corp. under its intellectual property
- * rights.  You may have additional license terms from the party that provided
+ * rights. You may have additional license terms from the party that provided
  * you this software, covering your right to use that party's intellectual
  * property rights.
  *
@@ -31,7 +32,7 @@
  * offer to sell, and import the Covered Code and derivative works thereof
  * solely to the minimum extent necessary to exercise the above copyright
  * license, and in no event shall the patent license extend to any additions
- * to or modifications of the Original Intel Code.  No other license or right
+ * to or modifications of the Original Intel Code. No other license or right
  * is granted directly or by implication, estoppel or otherwise;
  *
  * The above copyright and patent license is granted only if the following
@@ -43,11 +44,11 @@
  * Redistribution of source code of any substantial portion of the Covered
  * Code or modification with rights to further distribute source must include
  * the above Copyright Notice, the above License, this list of Conditions,
- * and the following Disclaimer and Export Compliance provision.  In addition,
+ * and the following Disclaimer and Export Compliance provision. In addition,
  * Licensee must cause all Covered Code to which Licensee contributes to
  * contain a file documenting the changes Licensee made to create that Covered
- * Code and the date of any change.  Licensee must include in that file the
- * documentation of any changes made by any predecessor Licensee.  Licensee
+ * Code and the date of any change. Licensee must include in that file the
+ * documentation of any changes made by any predecessor Licensee. Licensee
  * must include a prominent statement that the modification is derived,
  * directly or indirectly, from Original Intel Code.
  *
@@ -55,7 +56,7 @@
  * Redistribution of source code of any substantial portion of the Covered
  * Code or modification without rights to further distribute source must
  * include the following Disclaimer and Export Compliance provision in the
- * documentation and/or other materials provided with distribution.  In
+ * documentation and/or other materials provided with distribution. In
  * addition, Licensee may not authorize further sublicense of source of any
  * portion of the Covered Code, and must include terms to the effect that the
  * license from Licensee to its licensee is limited to the intellectual
@@ -80,10 +81,10 @@
  * 4. Disclaimer and Export Compliance
  *
  * 4.1. INTEL MAKES NO WARRANTY OF ANY KIND REGARDING ANY SOFTWARE PROVIDED
- * HERE.  ANY SOFTWARE ORIGINATING FROM INTEL OR DERIVED FROM INTEL SOFTWARE
- * IS PROVIDED "AS IS," AND INTEL WILL NOT PROVIDE ANY SUPPORT,  ASSISTANCE,
- * INSTALLATION, TRAINING OR OTHER SERVICES.  INTEL WILL NOT PROVIDE ANY
- * UPDATES, ENHANCEMENTS OR EXTENSIONS.  INTEL SPECIFICALLY DISCLAIMS ANY
+ * HERE. ANY SOFTWARE ORIGINATING FROM INTEL OR DERIVED FROM INTEL SOFTWARE
+ * IS PROVIDED "AS IS," AND INTEL WILL NOT PROVIDE ANY SUPPORT, ASSISTANCE,
+ * INSTALLATION, TRAINING OR OTHER SERVICES. INTEL WILL NOT PROVIDE ANY
+ * UPDATES, ENHANCEMENTS OR EXTENSIONS. INTEL SPECIFICALLY DISCLAIMS ANY
  * IMPLIED WARRANTIES OF MERCHANTABILITY, NONINFRINGEMENT AND FITNESS FOR A
  * PARTICULAR PURPOSE.
  *
@@ -92,14 +93,14 @@
  * COSTS OF PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES, OR FOR ANY INDIRECT,
  * SPECIAL OR CONSEQUENTIAL DAMAGES ARISING OUT OF THIS AGREEMENT, UNDER ANY
  * CAUSE OF ACTION OR THEORY OF LIABILITY, AND IRRESPECTIVE OF WHETHER INTEL
- * HAS ADVANCE NOTICE OF THE POSSIBILITY OF SUCH DAMAGES.  THESE LIMITATIONS
+ * HAS ADVANCE NOTICE OF THE POSSIBILITY OF SUCH DAMAGES. THESE LIMITATIONS
  * SHALL APPLY NOTWITHSTANDING THE FAILURE OF THE ESSENTIAL PURPOSE OF ANY
  * LIMITED REMEDY.
  *
  * 4.3. Licensee shall not export, either directly or indirectly, any of this
  * software or system incorporating such software without first obtaining any
  * required license or other approval from the U. S. Department of Commerce or
- * any other agency or department of the United States Government.  In the
+ * any other agency or department of the United States Government. In the
  * event Licensee exports any such software from the United States or
  * re-exports any such software from a foreign destination, Licensee shall
  * ensure that the distribution and export/re-export of the software is in
@@ -111,6 +112,42 @@
  * other governmental approval, or letter of assurance, without first obtaining
  * such license, approval or letter.
  *
+ *****************************************************************************
+ *
+ * Alternatively, you may choose to be licensed under the terms of the
+ * following license:
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ * 1. Redistributions of source code must retain the above copyright
+ *    notice, this list of conditions, and the following disclaimer,
+ *    without modification.
+ * 2. Redistributions in binary form must reproduce at minimum a disclaimer
+ *    substantially similar to the "NO WARRANTY" disclaimer below
+ *    ("Disclaimer") and any redistribution must be conditioned upon
+ *    including a substantially similar Disclaimer requirement for further
+ *    binary redistribution.
+ * 3. Neither the names of the above-listed copyright holders nor the names
+ *    of any contributors may be used to endorse or promote products derived
+ *    from this software without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+ * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+ * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
+ * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
+ * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
+ * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
+ * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+ * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
+ * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+ * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
+ * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ *
+ * Alternatively, you may choose to be licensed under the terms of the
+ * GNU General Public License ("GPL") version 2 as published by the Free
+ * Software Foundation.
+ *
  *****************************************************************************/
 
 #include "acpihelp.h"
@@ -119,7 +156,7 @@
  * ASL Keyword types and associated actual keywords.
  * This table was extracted from the ACPI specification.
  */
-const AH_ASL_KEYWORD        AslKeywordInfo[] =
+const AH_ASL_KEYWORD        Gbl_AslKeywordInfo[] =
 {
     {"AccessAttribKeyword", "Serial Bus Attributes (with legacy SMBus aliases)",
         ":= AttribQuick (SMBusQuick) | AttribSendReceive (SMBusSendReceive) | "
@@ -219,3 +256,46 @@ const AH_ASL_KEYWORD        AslKeywordInfo[] =
         ":= Transfer8 | Transfer16 | Transfer8_16"},
     {NULL, NULL, NULL}
 };
+
+/* Preprocessor directives */
+
+const AH_DIRECTIVE_INFO      Gbl_PreprocessorDirectives[] =
+{
+    {"#include \"Filename\"",               "Standard include of an ASCII ASL source code file"},
+    {"#include <Filename>",                 "Alternate syntax for #include, alternate search path"},
+    {"#includebuffer \"Filename\" <Name>",  "Include a binary file to create AML Buffer with ASL namepath"},
+    {"#includebuffer <Filename> <Name>",    "Alternate syntax for #includebuffer, alternate search path"},
+
+    {"",  ""},
+    {"#define <Name>, <Defined name>",      "Simple macro definition (full macros not supported at this time)"},
+    {"#define <Expression>, <Defined name>","Simple macro definition (full macros not supported at this time)"},
+    {"#undef <Defined name>",               "Delete a previous #define"},
+
+    {"",  ""},
+    {"#if <Expression>",                    "Evaluate <Expression> and test return value"},
+    {"#ifdef <Defined name>",               "Test existence of the <Defined Name>"},
+    {"#ifndef <Defined name>",              "Test non-existence of the <Defined Name>"},
+    {"#elif <Expression>",                  "Else-If contraction - evaluate #if <Expression>, test return value"},
+    {"#else",                               "Execute alternate case for a previous #if, #ifdef or #ifndef block"},
+    {"#endif",                              "Close a previous #if, #ifdef or #ifndef block"},
+
+    {"",   ""},
+    {"#line <LineNumber> [Filename]",       "Set the current ASL source code line number, optional filename"},
+
+    {"",   ""},
+    {"#error \"String\"",                   "Emit error message and abort compilation"},
+    {"#warning \"String\"",                 "Emit an iASL warning at this location in the ASL source"},
+
+    {"",  ""},
+    {"#pragma disable (Error number)",      "Disable an iASL error or warning number"},
+    {"#pragma message \"String\"",          "Emit an informational message to the output file(s)"},
+
+    {"",  ""},
+    {"__FILE__",                            "Return the simple filename of the current ASL file"},
+    {"__PATH__",                            "Return the full pathname of the current ASL file"},
+    {"__LINE__",                            "Return the current line number within the current ASL file"},
+    {"__DATE__",                            "Return the current date"},
+    {"__METHOD__",                          "Return the declared name of the current control method"},
+    {"__IASL__",                            "Permanently defined for the iASL compiler"},
+    {NULL,                                   NULL}
+};
